<?php
namespace Teknisa\GOP\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\FilterCriteria;

class Gop10001SimulacaoValoresController extends \Teknisa\GER\Controllers\TeknisaCrud {
    
    protected $parameterBag;
    protected $util;
    protected $environment;
    protected $dataSourceName;
    protected $parameterBagColums;
    protected $dataSourceManager;
    protected $service;
    
    public function __construct($crudService, $parameterBag, $service, $util, $environment, $dataSourceManager){
        $this->crudService          = $crudService;
        $this->service              = $service;
        $this->util                 = $util;
        $this->environment          = $environment;
        $this->dataSourceManager    = $dataSourceManager;
    }
   
    public function filterSimulation(DTO\Request $request, DTO\Response $response) {
        $row = $request->getRow();
        try {
            if(isset($row['NRLISTA']) && $row['NRLISTA'] != '') {
                $this->util->deleteLista($row['NRLISTA']);
            }
            $nrLista = $this->util->insertLista($row['CDFILIAL']);
            $conditions = array(
                array(
                    "columnName"=>"P_NRLISTA", 
                    "operator"=>"=", 
                    "value"=>$nrLista
                ),
                array(
                    "columnName"=>"P_IDPERIODOORCA", 
                    "operator"=>"=", 
                    "value"=>$row["P_IDPERIODOORCA"]
                ),
                array(
                    "columnName"=>"P_NRPERIODOORCA", 
                    "operator"=>"=", 
                    "value"=>$row["P_NRPERIODOORCA"]
                ),
                array(
                    "columnName"=>"P_NRANOORCAGOP", 
                    "operator"=>"=", 
                    "value"=>$row["P_NRANOORCAGOP"]
                ),
                array(
                    "columnName"=>"P_NRORG", 
                    "operator"=>"=", 
                    "value"=>$this->environment->getNrOrg()
                )
            );
            $result = $this->crudService->getFilteredDataSet('gop10001_simulacaoValores', $conditions);
            $dados = $result->getRows();
            $dataSet = array(
                "data"=>$dados,
                "nrLista"=>$nrLista
            );
            $response->addDataSet(new DataSet('success', $dataSet));
        }catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500)); 
        }
    }
    
    public function verifyParamVrFaturamento(DTO\Request $request, DTO\Response $response) {
        $row = $request->getRow();
        try{
            if(!is_string($row["CDFILIAL"]) && count($row["CDFILIAL"]) > 1){
                $row["CDFILIAL"] = "P";
            }
            
            $paramVrFaturamento = $this->service->verifyParamVrFaturamento($row);
            $dataSet = array (
                'VRFATURAMENTO' => $paramVrFaturamento
            );
            $response->addDataSet(new DataSet('result', $dataSet));
            
        }catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function saveCalculation(DTO\Request $request, DTO\Response $response) {
        $row = $request->getRow();
        try{
            //$arrayData = array('ARRAYDATALOADED'); usar & para referencia so quando recebe
            $arrayData = $this->getLoadedData($row['BACKUP']);
            // if(isset($config['RATEIO']) || isset($config['RATEIO_ZERADO'])) {
                $list = $this->util->insertLista($arrayData['ARRAYKEYSDATALOADED']);
                $resultFatCons = $this->service->getDataNotExistsBkpFatCons($list, $row['PARAMSSIMULATION']);
                $resultMaoObra = $this->service->getDataNotExistsBkpMaoObra($list, $row['PARAMSSIMULATION']);
                $resultDetail = $this->service-> getDataNotExistsBkpDetail($list, $row['PARAMSSIMULATION']);
                //$arrayDataNotLoaded = $this->rateioDetalhamento($result);
            // } 

            $this->updateCalc($arrayData['ARRAYDATALOADED']);
            $this->util->deleteLista($list);
        }catch(\Exception $e) {
            $response->setError(new Error ($e->getMessage(), 500));
        }
    }
    
    private function getLoadedData($backup) {
        $arrayKeysDataLoaded = array();
        $arrayDataLoaded = array();
        $stringConcat = '';
        foreach($backup as $keyUnit => $unit) { 
            foreach($unit as $keyIdTipoOrca => $idTipoOrca) { 
                if($keyIdTipoOrca != 'VRFATURAMENTO') { // conferir aonde ta sendo usado
                    if(count($idTipoOrca)) {
                        foreach($idTipoOrca as $keyDetailUnit => $detailUnit) {
                             $detail = substr($keyDetailUnit, 1); // pensar em uma função tipo treatkey
                            if(array_key_exists('MESES', $detailUnit)){
                                $stringConcat = $keyUnit.$keyIdTipoOrca.$keyDetailUnit;
                                array_push($arrayKeysDataLoaded, $stringConcat); 
                                foreach($detailUnit['MESES'] as $key => $month) {
                                    array_push($arrayDataLoaded, $month); 
                                }
                            }
                        }
                    }
                }
            }
        }
        //[JANEIRO, FEVEREIRO...], SE TIVER RATEIO USO[9999CONSUMO00001, 9999CONSUMO0003] (RETORNAR TODOS QUE NÃO FORAM CARREGADOS)
        $arrayData = array('ARRAYDATALOADED'=> $arrayDataLoaded, 'ARRAYKEYSDATALOADED'=> $arrayKeysDataLoaded);
        
        return $arrayData;
    }
    
    private function updateCalc($arrayDataLoaded) {
        foreach($arrayDataLoaded as $row) {
            // $params = array (
            //     "P_IDTIPOORCAOP" => $row['IDTIPOORCAOP'],
            //     "P_CDFILIAL"  => $row['CDFILIAL'],    
            //     "P_CODIGO"  => $row['CODIGO'],
            //     "P_MES"     => $row['MES'],
            //     "P_QTORCAMENTO" => $row['QTORCAMENTO']
            // );
        }
    }
}


