<?php
namespace Teknisa\GOP\Modules\Relatorio\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\Report\ReportService;
use Zeedhi\Framework\Report\Strategy\BirtStrategy;
use Teknisa\Libs\Util\NewCode;


class Gop01600ComparativoOrcamento extends \Zeedhi\Framework\Controller\Report{
    
    protected $birtStrategy;
    protected $newCode;
    protected $environment;
    protected $util;
    
    public function __construct ($reportService, $birtStrategy, $newCode, $environment, $util) {

        $this->birtStrategy        = $birtStrategy;
        $this->reportService       = $reportService;
        $this->newCode             = $newCode;
        $this->environment         = $environment;
        $this->util                = $util;
    }
 
    protected $reportMapping = array (
        'GOP01600' =>
            array (
                'strategy' => 'BIRT',
                'parameterMapping' =>
                    array(
                        "CDGRUPFILI"      => "P_CDGRUPFILI",
                        "CDEMPRESA"       => "P_CDEMPRESA",
                        "CDAREAGERE"      => "P_CDAREAGERE",
                        "CDSEGMER"        => "P_CDSEGMER",
                        "CDSUPERVISOR"    => "P_CDSUPERVISOR",
                        "NRLISTA"         => "P_NRLISA",
                        "NRANOORCAGOP"    => "P_NRANOORCAGOP",
                        "IDPERIODOORCA"   => "P_IDPERIODOORCA",
                        "NRPERIODOORCA"   => "P_NRPERIODOORCA",
                        "EXIBERELACUNI"   => "P_EXIBERELACUNI",
                        "EXIBUNINAORELAC" => "P_EXIBUNINAORELAC",
                        "NRORG"           => "P_NRORG"
                    )
            )
    );
    
    public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        $row['__report_name'] = $row['RELATORIO'];
        $row['NRORG'] = $this->environment->getNrorg();
        $nrLista = $this->util->insertLista($row['CDFILIAL']);
        $row['NRLISTA'] = $nrLista;
        $row['CDGRUPFILI'] = !isset($row['CDGRUPFILI']) || empty($row['CDGRUPFILI']) ? 'T' : $row['CDGRUPFILI'];
        $row['CDEMPRESA'] = !isset($row['CDEMPRESA']) || empty($row['CDEMPRESA']) ? 'T' : $row['CDEMPRESA'];
        $row['CDAREAGERE'] = !isset($row['CDAREAGERE']) || empty($row['CDAREAGERE']) ? 'T' : $row['CDAREAGERE'];
        $row['CDSEGMER'] = !isset($row['CDSEGMER']) || empty($row['CDSEGMER']) ? 'T' : $row['CDSEGMER'];
        $row['CDSUPERVISOR'] = !isset($row['CDSUPERVISOR']) || empty($row['CDSUPERVISOR']) ? 'T' : $row['CDSUPERVISOR'];
        $this->birtStrategy->setReportFormat($row["ABRIRCOMO"]);
    }
    
    public function afterProcessReport(DTO\Request\Row $request, DTO\Response $response, $report) {
        $row = $request->getRow();
        $this->util->deleteLista($row['NRLISTA']);
    }
}

